==> hive-apache-3.1.2-5-sources.jar: org/apache/hadoop/hive/ql/io/ParquetFileStorageFormatDescriptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.io;

import java.util.Set;

import org.apache.hadoop.hive.ql.io.parquet.MapredParquetInputFormat;
import org.apache.hadoop.hive.ql.io.parquet.MapredParquetOutputFormat;
import org.apache.hadoop.hive.ql.io.parquet.serde.ParquetHiveSerDe;

import io.prestosql.hive.$internal.com.google.common.collect.ImmutableSet;

public class ParquetFileStorageFormatDescriptor extends AbstractStorageFormatDescriptor {
  @Override
  public Set<String> getNames() {
    return ImmutableSet.of(IOConstants.PARQUETFILE, IOConstants.PARQUET);
  }
  @Override
  public String getInputFormat() {
    return MapredParquetInputFormat.class.getName();
  }
  @Override
  public String getOutputFormat() {
    return MapredParquetOutputFormat.class.getName();
  }
  @Override
  public String getSerde() {
    return ParquetHiveSerDe.class.getName();
  }
}

==> hive-apache-3.1.2-17-sources.jar: org/apache/hadoop/hive/ql/io/ParquetFileStorageFormatDescriptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.io;

import java.util.Set;

import org.apache.hadoop.hive.ql.io.parquet.MapredParquetInputFormat;
import org.apache.hadoop.hive.ql.io.parquet.MapredParquetOutputFormat;
import org.apache.hadoop.hive.ql.io.parquet.serde.ParquetHiveSerDe;

import io.trino.hive.$internal.com.google.common.collect.ImmutableSet;

public class ParquetFileStorageFormatDescriptor extends AbstractStorageFormatDescriptor {
  @Override
  public Set<String> getNames() {
    return ImmutableSet.of(IOConstants.PARQUETFILE, IOConstants.PARQUET);
  }
  @Override
  public String getInputFormat() {
    return MapredParquetInputFormat.class.getName();
  }
  @Override
  public String getOutputFormat() {
    return MapredParquetOutputFormat.class.getName();
  }
  @Override
  public String getSerde() {
    return ParquetHiveSerDe.class.getName();
  }
}
